==> hsahomology_1.7.0.tar.gz: hsahomology/man/hsahomologyLL2HGID.Rd <==
\name{hsahomologyLL2HGID}
\alias{hsahomologyLL2HGID}
\alias{hsahomologyACC2HGID}
\alias{hsahomologyHGID2LL}
\alias{hsahomologyHGID2ACC} 
\title{Mappings between public database ids and NCBI's Internal
  HomoloGeneIDs for Homo sapiens}  
\description{
  Provides mappings between public database ids and internal
  HomoloGeneIDs (HGID) used by NCBI to represent sequences for
  Homo sapiens. Public database ids include LocusLink ids (LL) and GenBank
  Accesion/RefSeq numbers (ACC).     
}
\details{
  Each object is an environment object with key and value pairs. Keys
  are ids specified by the abbreviation proceeding the number 2 of the
  name of an object (e.g. LL in hsahomologyLL2HGID) and values are ids
  specified by the abbreviation following the number 2 (e.g. HGID in
  hsahomologyLL2HGID). Values may be vectors of length 1 or greater depending
  on whether a key id can be mapped to only one or more other
  ids. Vector names are the code used by NCBI for various organism.

  hsahomologyLL2HGID or hsahomologyACC2HGID can be used to find the
  HomoloGeneIDs for a give LocusLink id or GenBank/RefSeq accession
  number and then the data for homologous genes found in other
  organisms.  
  
  Mappings contained were based on data provided by HomoloGene.
  
  HomoloGene:\url{ ftp://ftp.ncbi.nih.gov/pub/HomoloGene/old/hmlg.ftp}. Built: HomoloGene built date not available

  Packagebuilt Fri Jan  7 09:30:30 2005
}
\references{
\url{http://www.ncbi.nih.gov/entrez/query.fcgi?db=homologene}
}
\examples{
    require("annotate") || stop("annotate unavailable")
    xx <- as.list(hsahomologyLL2HGID)
        if(length(xx) > 5){
                # Get the value of the first key
                xx[2]
                # Get the value for a few keys
                if(length(xx) >= 3){
                        xx[2:4]
                }
        }
}
\keyword{datasets}

==> hsahomology_1.8.4.tar.gz: hsahomology/man/hsahomologyLL2HGID.Rd <==
\name{hsahomologyLL2HGID}
\alias{hsahomologyLL2HGID}
\alias{hsahomologyACC2HGID}
\alias{hsahomologyHGID2LL}
\alias{hsahomologyHGID2ACC} 
\title{Mappings between public database ids and NCBI's Internal
  HomoloGeneIDs for Homo sapiens}  
\description{
  R environments that provides mappings between public database ids and internal
  HomoloGeneIDs (HGID) used by NCBI to represent sequences for
  Homo sapiens. Public database ids include LocusLink ids (LL) and GenBank
  Accesion/RefSeq numbers (ACC).     
}
\details{
  Each R environment provides mapping between either HomoloGeneIds and
  database ids, or the converse. The mapping direction is indicated by
  the name of the environment. For instance, hsahomologyACC2HGID provides
  mappings between GenBank accession numbers and HomoloGeneIds.

  For each environment, a given id will map to a named vector of ids,
  the names of which are the NCBI code for that organism.
 
  Mappings contained were based on data provided by HomoloGene.
  
  HomoloGene:\url{ ftp://ftp.ncbi.nih.gov/pub/HomoloGene/old/hmlg.ftp}. Built: HomoloGene built date not available

  Packagebuilt Sun May 15 12:34:37 2005
}
\references{
\url{http://www.ncbi.nih.gov/entrez/query.fcgi?db=homologene}
}
\examples{
    require("annotate") || stop("annotate unavailable")
    xx <- as.list(hsahomologyLL2HGID)
        if(length(xx) > 5){
                # Get the value of the first key
                xx[2]
                # Get the value for a few keys
                if(length(xx) >= 3){
                        xx[2:4]
                }
        }
}
\keyword{datasets}
